summaryrefslogtreecommitdiffstats
path: root/parts/classview/classtooldlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/classview/classtooldlg.h')
-rw-r--r--parts/classview/classtooldlg.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/parts/classview/classtooldlg.h b/parts/classview/classtooldlg.h
index 54d1d1cd..9b722346 100644
--- a/parts/classview/classtooldlg.h
+++ b/parts/classview/classtooldlg.h
@@ -18,7 +18,7 @@
#include <tqlabel.h>
#include <tqtoolbutton.h>
#include <tqcombobox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include "classtoolwidget.h"
#include "parseditem.h"
@@ -47,7 +47,7 @@ public slots:
void viewNone();
/** View the parents of the current class. */
void viewParents();
/** View the children of the current class. */
void viewChildren();
/** View all classes that has this class as an attribute. */
void viewClients();
@@ -76,7 +76,7 @@ private:
TQComboBox *class_combo;
TQToolButton *parents_button;
- TQToolButton *children_button;
+ TQToolButton *tqchildren_button;
TQToolButton *clients_button;
TQToolButton *suppliers_button;
TQToolButton *methods_button;
@@ -47,7 +47,7 @@ public slots:
/** View the parents of the current class. */
void viewParents();
- /** View the children of the current class. */
+ /** View the tqchildren of the current class. */
void viewChildren();
/** View all classes that has this class as an attribute. */